import 'package:cpt_auth/modules/select_estate/select_estate_state.dart';
import 'package:cs_resources/generated/assets.dart';
import 'package:cs_resources/generated/l10n.dart';
import 'package:cs_resources/theme/app_colors_theme.dart';
import 'package:flutter/material.dart';
import 'package:auto_route/auto_route.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:hooks_riverpod/hooks_riverpod.dart';
import 'package:router/ext/auto_router_extensions.dart';
import 'package:shared/utils/log_utils.dart';
import 'package:widgets/ext/ex_widget.dart';
import 'package:widgets/my_appbar.dart';
import 'package:widgets/my_button.dart';
import 'package:widgets/my_load_image.dart';
import 'package:widgets/my_text_field.dart';
import 'package:widgets/my_text_view.dart';
import 'package:widgets/widget_export.dart';

import '../../router/page/auth_page_router.dart';
import 'select_estate_view_model.dart';

@RoutePage()
class SelectEstatePage extends HookConsumerWidget {
  SelectEstatePage({Key? key}) : super(key: key);

  //启动当前页面
  static void startInstance({BuildContext? context}) {
    if (context != null) {
      context.router.push(SelectEstatePageRoute());
    } else {
      appRouter.push(SelectEstatePageRoute());
    }
  }

  // 为需要测量的控件创建 GlobalKey
  final GlobalKey _appbarKey = GlobalKey();
  final GlobalKey _topImageKey = GlobalKey();
  final GlobalKey _titleKey = GlobalKey();
  final GlobalKey _inputKey = GlobalKey();
  final GlobalKey _descriptionKey = GlobalKey();
  final GlobalKey _buttonKey = GlobalKey();

  @override
  Widget build(BuildContext context, WidgetRef ref) {
    final viewModel = ref.watch(selectEstateViewModelProvider.notifier);
    final state = ref.watch(selectEstateViewModelProvider);

    // 获取屏幕高度
    final screenHeight = MediaQuery.of(context).size.height;
    final statusBarHeight = MediaQuery.of(context).padding.top;
    final navigationBarHeight = MediaQuery.of(context).padding.bottom;

    useEffect(() {
      double usedHeight = 0;
      // 组件挂载时执行,获取控件高度
      WidgetsBinding.instance.addPostFrameCallback((_) {
        // 获取各个控件的高度
        usedHeight += _appbarKey.currentContext?.size?.height ?? 0;
        usedHeight += _topImageKey.currentContext?.size?.height ?? 0;
        usedHeight += _titleKey.currentContext?.size?.height ?? 0;
        usedHeight += _inputKey.currentContext?.size?.height ?? 0;
        usedHeight += _descriptionKey.currentContext?.size?.height ?? 0;
        usedHeight += _buttonKey.currentContext?.size?.height ?? 0;

        // 计算剩余空间
        double remainingSpace = screenHeight - statusBarHeight - navigationBarHeight - usedHeight - 38 - 28 - 20 - 19;

        Log.d("计算剩余空间:$remainingSpace");

        if (remainingSpace > 0) {
          // 设置一个状态来存储剩余空间的高度
          viewModel.setRemainingSpace(remainingSpace);
        }
      });
      return () {
        // 组件卸载时执行
      };
    }, []);

    return Scaffold(
      appBar: MyAppBar.appBar(context, S.current.yy_home_accounts, key: _appbarKey),
      backgroundColor: context.appColors.backgroundDefault,
      body: SingleChildScrollView(
        scrollDirection: Axis.vertical,
        physics: const BouncingScrollPhysics(),
        child: Container(
          padding: const EdgeInsets.symmetric(horizontal: 38),
          width: double.infinity,
          child: Column(
            mainAxisSize: MainAxisSize.max,
            crossAxisAlignment: CrossAxisAlignment.center,
            children: [
              //顶部图片
              MyAssetImage(
                key: _topImageKey,
                Assets.authChooseEstateBuilding,
                width: 267,
                height: 158,
              ).marginOnly(top: 28, bottom: 38),

              MyTextView(
                key: _titleKey,
                S.current.estate_or_building_name,
                fontSize: 23,
                marginBottom: 20,
                textAlign: TextAlign.center,
                isFontMedium: true,
                textColor: context.appColors.textBlack,
              ),

              //输入资产的名称
              _buildInputLayout(
                context,
                state,
                "estate",
                key: _inputKey,
                textInputAction: TextInputAction.done,
                onSubmit: (formKey, value) {
                  state.formData[formKey]!['focusNode'].unfocus();
                },
              ),

              MyTextView(
                key: _descriptionKey,
                S.current.estate_name_desc,
                fontSize: 15,
                marginTop: 19,
                isFontMedium: true,
                textColor: context.appColors.textBlack,
              ),

              SizedBox(
                height: state.remainingSpace, // 使用剩余空间的值
              ),

              MyButton(
                key: _buttonKey,
                onPressed: viewModel.submitEstate,
                text: S.current.next,
                textColor: Colors.white,
                backgroundColor: context.appColors.btnBgDefault,
                fontWeight: FontWeight.w500,
                type: ClickType.throttle,
                fontSize: 16,
                minHeight: 50,
                radius: 5,
              ).marginOnly(top: 40, bottom: 30),
            ],
          ),
        ),
      ),
    );
  }

  /// 输入框
  Widget _buildInputLayout(
    BuildContext context,
    SelectEstateState state,
    String formKey, {
    Key? key,
    double marginTop = 0,
    bool? showRightIcon = false, //是否展示右侧的布局
    Widget? rightWidget, //右侧的布局
    TextInputType textInputType = TextInputType.text,
    String? errorText,
    bool obscureText = false,
    TextInputAction textInputAction = TextInputAction.done,
    Function? onSubmit,
  }) {
    return IgnoreKeyboardDismiss(
      child: MyTextField(
        formKey,
        key: key,
        fillBackgroundColor: context.appColors.authFiledBG,
        state.formData[formKey]!['value'],
        hintText: state.formData[formKey]!['hintText'],
        hintStyle: TextStyle(
          color: context.appColors.authFiledHint,
          fontSize: 16.0,
          fontWeight: FontWeight.w500,
        ),
        controller: state.formData[formKey]!['controller'],
        focusNode: state.formData[formKey]!['focusNode'],
        margin: EdgeInsets.only(top: marginTop),
        padding: const EdgeInsets.symmetric(horizontal: 12, vertical: 3),
        showDivider: false,
        height: 44,
        style: TextStyle(
          color: context.appColors.authFiledText,
          fontSize: 16.0,
          fontWeight: FontWeight.w500,
        ),
        inputType: textInputType,
        textInputAction: textInputAction,
        onSubmit: onSubmit,
        cursorColor: context.appColors.authFiledText,
        obscureText: obscureText,
        errorText: errorText,
        showLeftIcon: true,
        showRightIcon: showRightIcon,
        rightWidget: rightWidget,
      ),
    );
  }
}
